@@ -5,9 +5,15 @@ for demo and tests.
 
 """
 import numpy as np
+try:
+    import torch
+    with_torch = True
+except Exception as e:
+    with_torch = False
 
 
 from ..func import Func
+from ..utils import _cores_mults
 
 
 class FuncDemoExponential(Func):
@@ -21,7 +27,9 @@ class FuncDemoExponential(Func):
         Note:
             See Momin Jamil, Xin-She Yang. "A literature survey of benchmark
             functions for global optimization problems". Journal of
-            Mathematical Modelling and Numerical Optimisation 2013; 4:150-194.
+            Mathematical Modelling and Numerical Optimisation 2013; 4:150-194
+            ("54. Exponential Function"; Continuous, Differentiable,
+            Non-Separable, Scalable, Multimodal).
 
         """
         super().__init__(d, name='Exponential')
@@ -34,5 +42,18 @@ class FuncDemoExponential(Func):
     def _calc(self, x):
         return -np.exp(-0.5 * np.sum(x**2)) + self.dy
 
+    def _calc_pt(self, x):
+        if not with_torch:
+            raise ValueError('Torch is not available')
+
+        dy = torch.tensor(self.dy)
+
+        return -torch.exp(-0.5 * torch.sum(x**2)) + dy
+
     def _comp(self, X):
         return -np.exp(-0.5 * np.sum(X**2, axis=1)) + self.dy
+
+    def _cores(self, X):
+        Y = _cores_mults([np.exp(-0.5 *x**2) for x in X.T])
+        Y[-1] *= -1.
+        return Y
